@@ -21,6 +21,9 @@ package org.jboss.modules;
 import java.io.File;
 import java.nio.file.Path;
 import java.security.AccessController;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import java.util.jar.JarFile;
 import org.jboss.modules.filter.PathFilter;
 
@@ -32,13 +35,6 @@ import org.jboss.modules.filter.PathFilter;
  * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
  */
 public final class ResourceLoaders {
-    static final boolean USE_INDEXES;
-    static final boolean WRITE_INDEXES;
-
-    static {
-        USE_INDEXES = Boolean.parseBoolean(AccessController.doPrivileged(new PropertyReadAction("jboss.modules.use-indexes", "false")));
-        WRITE_INDEXES = USE_INDEXES && Boolean.parseBoolean(AccessController.doPrivileged(new PropertyReadAction("jboss.modules.write-indexes", "false")));
-    }
 
     private ResourceLoaders() {
     }
@@ -50,9 +46,16 @@ public final class ResourceLoaders {
      * @param name the name of the resource root
      * @param root the root file of the resource loader
      * @return the resource loader
+     * @deprecated Use {@link #createPathResourceLoader(Path)} instead.
      */
-    public static ResourceLoader createFileResourceLoader(final String name, final File root) {
-        return new FileResourceLoader(name, root, AccessController.getContext());
+    @Deprecated
+    public static IterableResourceLoader createFileResourceLoader(final String name, final File root) {
+        return createPathResourceLoader(name, root.toPath());
+    }
+
+    @Deprecated
+    public static ResourceLoader createFileResourceLoader$$bridge(final String name, final File root) {
+        return createFileResourceLoader(name, root);
     }
 
     /**
@@ -62,9 +65,11 @@ public final class ResourceLoaders {
      * @param name the name of the resource root
      * @param root the root file of the resource loader
      * @return the resource loader
+     * @deprecated Use {@link #createFileResourceLoader(String, File)} instead.
      */
+    @Deprecated
     public static IterableResourceLoader createIterableFileResourceLoader(final String name, final File root) {
-        return new FileResourceLoader(name, root, AccessController.getContext());
+        return createFileResourceLoader(name, root);
     }
 
     /**
@@ -74,11 +79,29 @@ public final class ResourceLoaders {
      * @param name the name of the resource root
      * @param jarFile the backing JAR file
      * @return the resource loader
+     * @deprecated Use {@link #createJarResourceLoader(JarFile)} instead.
      */
-    public static ResourceLoader createJarResourceLoader(final String name, final JarFile jarFile) {
+    @Deprecated
+    public static IterableResourceLoader createJarResourceLoader(final String name, final JarFile jarFile) {
         return new JarFileResourceLoader(name, jarFile);
     }
 
+    /**
+     * Create a JAR-backed resource loader.  JAR resource loaders do not have native library support.
+     * Created classes have a code source with a {@code jar:} URL; nested JARs are not supported.
+     *
+     * @param jarFile the backing JAR file
+     * @return the resource loader
+     */
+    public static IterableResourceLoader createJarResourceLoader(final JarFile jarFile) {
+        return new JarFileResourceLoader("unnamed", jarFile);
+    }
+
+    @Deprecated
+    public static ResourceLoader createJarResourceLoader$$bridge(final String name, final JarFile jarFile) {
+        return createJarResourceLoader(name, jarFile);
+    }
+
     /**
      * Create a JAR-backed resource loader.  JAR resource loaders do not have native library support.
      * Created classes have a code source with a {@code jar:} URL; nested JARs are not supported.  The given
@@ -87,11 +110,24 @@ public final class ResourceLoaders {
      * @param name the name of the resource root
      * @param jarFile the backing JAR file
      * @return the resource loader
+     * @deprecated Use {@link #createJarResourceLoader(JarFile, String)} instead.
      */
     public static IterableResourceLoader createJarResourceLoader(final String name, final JarFile jarFile, final String relativePath) {
         return new JarFileResourceLoader(name, jarFile, relativePath);
     }
 
+    /**
+     * Create a JAR-backed resource loader.  JAR resource loaders do not have native library support.
+     * Created classes have a code source with a {@code jar:} URL; nested JARs are not supported.  The given
+     * relative path within the JAR is used as the root of the loader.
+     *
+     * @param jarFile the backing JAR file
+     * @return the resource loader
+     */
+    public static IterableResourceLoader createJarResourceLoader(final JarFile jarFile, final String relativePath) {
+        return new JarFileResourceLoader("unnamed", jarFile, relativePath);
+    }
+
     /**
      * Create a JAR-backed iterable resource loader.  JAR resource loaders do not have native library support.
      * Created classes have a code source with a {@code jar:} URL; nested JARs are not supported.
@@ -99,9 +135,11 @@ public final class ResourceLoaders {
      * @param name the name of the resource root
      * @param jarFile the backing JAR file
      * @return the resource loader
+     * @deprecated Use {@link #createJarResourceLoader(JarFile)} instead.
      */
+    @Deprecated
     public static IterableResourceLoader createIterableJarResourceLoader(final String name, final JarFile jarFile) {
-        return new JarFileResourceLoader(name, jarFile);
+        return createJarResourceLoader(name, jarFile);
     }
 
     /**
@@ -113,7 +151,7 @@ public final class ResourceLoaders {
      * @return the filtered resource loader
      */
     public static ResourceLoader createFilteredResourceLoader(final PathFilter pathFilter, final ResourceLoader originalLoader) {
-        return new FilteredResourceLoader(pathFilter, originalLoader);
+        return originalLoader instanceof IterableResourceLoader ? new FilteredIterableResourceLoader(pathFilter, (IterableResourceLoader) originalLoader) : new FilteredResourceLoader(pathFilter, originalLoader);
     }
 
     /**
@@ -124,18 +162,61 @@ public final class ResourceLoaders {
      * @param originalLoader the original loader to apply to
      * @return the filtered resource loader
      */
-    public static IterableResourceLoader createIterableFilteredResourceLoader(final PathFilter pathFilter, final IterableResourceLoader originalLoader) {
+    public static IterableResourceLoader createFilteredResourceLoader(final PathFilter pathFilter, final IterableResourceLoader originalLoader) {
         return new FilteredIterableResourceLoader(pathFilter, originalLoader);
     }
 
+    /**
+     * Create a filtered view of an iterable resource loader, which allows classes to be included or excluded on a name basis.
+     * The given filter is matched against the actual class or resource name, not the directory name.
+     *
+     * @param pathFilter the path filter to apply
+     * @param originalLoader the original loader to apply to
+     * @return the filtered resource loader
+     * @deprecated Use {@link #createFileResourceLoader(String, File)} instead.
+     */
+    public static IterableResourceLoader createIterableFilteredResourceLoader(final PathFilter pathFilter, final IterableResourceLoader originalLoader) {
+        return createFilteredResourceLoader(pathFilter, originalLoader);
+    }
+
     /**
      * Create a NIO2 Path-backed iterable resource loader.
      *
      * @param name the name of the resource root
      * @param path the root path of the resource loader
      * @return the resource loader
+     * @deprecated Use {@link #createPathResourceLoader(Path)} instead.
      */
+    @Deprecated
     public static IterableResourceLoader createPathResourceLoader(final String name, final Path path) {
         return new PathResourceLoader(name, path, AccessController.getContext());
     }
+
+    /**
+     * Create a NIO2 Path-backed iterable resource loader.
+     *
+     * @param path the root path of the resource loader
+     * @return the resource loader
+     */
+    public static IterableResourceLoader createPathResourceLoader(final Path path) {
+        return new PathResourceLoader("unnamed", path, AccessController.getContext());
+    }
+
+    /**
+     * Create a service resource loader.  This is a resource loader which answers service load requests with a preset
+     * implementation name.
+     *
+     * @param serviceMap a map of service types to a list of implementation names (must not be {@code null})
+     * @return the resource loader (not {@code null})
+     */
+    public static ResourceLoader createServiceResourceLoader(final Map<String, List<String>> serviceMap) {
+        final Map<String, URLConnectionResource> map = new HashMap<>();
+        for (Map.Entry<String, List<String>> entry : serviceMap.entrySet()) {
+            final String serviceName = entry.getKey();
+            final List<String> implNames = entry.getValue();
+            final URLConnectionResource resource = ServiceResourceLoader.createResource(implNames);
+            map.put(serviceName, resource);
+        }
+        return new ServiceResourceLoader(map);
+    }
 }
