@@ -584,7 +584,7 @@ public final class ModuleXmlParser {
         String name = null;
         String slot = null;
         boolean noSlots = atLeast1_6(reader);
-        final Set<String> required = new HashSet<>(LIST_A_NAME_A_SLOT);
+        final Set<String> required = noSlots ? new HashSet<>(LIST_A_NAME) : new HashSet<>(LIST_A_NAME_A_SLOT);
         for (int i = 0; i < count; i ++) {
             validateAttributeNamespace(reader, i);
             final String attribute = reader.getAttributeName(i);
@@ -598,13 +598,15 @@ public final class ModuleXmlParser {
         if (! required.isEmpty()) {
             throw missingAttributes(reader, required);
         }
-        if (noSlots) {
-            if (! name.equals(moduleName)) {
-                throw invalidModuleName(reader, moduleName);
-            }
-        } else {
-            if (! ModuleIdentifier.fromString(moduleName).equals(ModuleIdentifier.create(name, slot))) {
-                throw invalidModuleName(reader, moduleName);
+        if (moduleName != null) {
+            if (noSlots) {
+                if (!name.equals(moduleName)) {
+                    throw invalidModuleName(reader, moduleName);
+                }
+            } else {
+                if (!ModuleIdentifier.fromString(moduleName).equals(ModuleIdentifier.create(name, slot))) {
+                    throw invalidModuleName(reader, moduleName);
+                }
             }
         }
         int eventType;
@@ -627,7 +629,7 @@ public final class ModuleXmlParser {
         String slot = null;
         boolean is1_6 = atLeast1_6(reader);
         Version version = null;
-        final Set<String> required = is1_6 ? new HashSet<>(LIST_A_NAME) : new HashSet<>(LIST_A_NAME);
+        final Set<String> required = new HashSet<>(LIST_A_NAME);
         for (int i = 0; i < count; i ++) {
             validateAttributeNamespace(reader, i);
             final String attribute = reader.getAttributeName(i);
@@ -670,7 +672,6 @@ public final class ModuleXmlParser {
         }
         Set<String> visited = new HashSet<>();
         int eventType;
-        boolean gotPerms = false;
         for (;;) {
             eventType = reader.nextTag();
             switch (eventType) {
@@ -704,7 +705,7 @@ public final class ModuleXmlParser {
                                 } catch (IllegalArgumentException ignored) {}
                             }
                         }); break;
-                        case E_PERMISSIONS:  parsePermissions(reader, moduleLoader, realModuleName, specBuilder); gotPerms = true; break;
+                        case E_PERMISSIONS:  parsePermissions(reader, moduleLoader, realModuleName, specBuilder); break;
                         case E_PROVIDES:     if (is1_8) parseProvidesType(reader, specBuilder); else throw unexpectedContent(reader); break;
                         default: throw unexpectedContent(reader);
                     }
